/* CalcMktPortfolio.sas uses the fitted variables of the efficient frontier to 
	find the market portfolio. */

	/* Risk-Free Daily RoR. */
	%let r_free = 0.000111;

	   proc sql noprint;
	/* Get the fitted intercept. */
      select estimate
	         into :c
	         from RDExamp.estimates
	         where variable = "Intercept";

	/* Get the fitted quadratic parameter. */
	      select estimate
	         into :a
	         from RDExamp.estimates
	         where variable = "OO2";

	/* Get the fitted linear parameter. */
	      select estimate
         into :b
	         from RDExamp.estimates
	         where variable = "OptObjective";

	/* Use the risk-free RoR and the parameters to calculate  */
	/* the RoR of the market portfolio.                       */
	         insert into RDExamp.estimates
	         set variable = "Mkt RoR",
		          estimate = (2*&a*&r_free + 
			                   sqrt((4*(&a**2)*&r_free**2 +
			                   4*&a*(&r_free*&b + &c) )))
			                   / (2*&a);

 /* Get the mkt portfolio RoR. */
	         select estimate
			      into :u
			      from RDExamp.estimates
			      where variable = "Mkt RoR";

	/* Calculate the ES of the mkt portfolio. */
			   insert into RDExamp.estimates
			      set variable = "Mkt ES",
			          estimate = &a*&u**2 + &b*&u + &c;

	/* Get the ES of the mkt portfolio. */
			   select estimate
			      into :r_mkt
			      from RDExamp.estimates
			      where variable = "Mkt ES";

	   quit;

	/* Use PROC RISK to create the mkt portfolio weights. */
	   proc risk;
	      environment open = RDExamp.optimex;

	/* Set analysis options. */
			setoptions optsummary;

	/* Create an optimization analysis. */
       optimization Stock_Optimization3
          simulation = Stock_Sim
	          horizon = (1)
		       objective = return
	          subjectto = (es = (&r_mkt))
	          bounds = RDExamp.stockbound
	          lincon = RDExamp.stocklin;

	/* Create the analysis project Mkt_Portfolio. */
	       project Mkt_Portfolio
			          data = (Mkt_Data)
			          portfolio = Stock_File
			          analysis = (Stock_Optimization3)
			          numeraire = USD
			          rundate = "30May14"d
			          crossclass = cc1
			          out = Mkt_Portfolio;

/* Run the analysis project. */
			 runproject Mkt_Portfolio 
			    options = (outall);

			 environment save;

   run;
