/* Analyze the initial portfolio. Optimize the weighting scheme
for the same level of risk. */
proc risk;
environment open = RDExamp.optimex;
/* Set analysis options. */
setoptions optsummary;
/* Create a simulation analysis using the */
/* covariance matrix created in RiskSetupA.sas */
simulation Stock_Sim
interval = weekday
method = covariance
seed = 12345
ndraw = 1500
data = Cov_Mat
horizon = (1);
/* Create the analysis project Stock_Proj. */
project Stock_Proj
data = (Mkt_Data)
portfolio = Stock_File
analysis = (Stock_Sim)
numeraire = USD
rundate = "30May14"d
crossclass = cc1
out = Initial_Stock_Results;
/* Run the analysis project. */
runproject Stock_Proj
options = (outall);
environment save;
run;
/* Create library to Initial_Stock_Results. */
%macro createlib;
%let inpath=%sysfunc(pathname(RDExamp,L));
%if %index(&inpath,\) %then %let sep=\; %else %let sep=/;
libname stockres "&loc.&sep.optimex&sep.Initial_Stock_Results";
%mend;
%createlib;
/* Use SQL to store ES as a % in a macro. */
proc sql noprint;
select ES / MtM
into :ESPct
from stockres.simstat
where Company = "+";
quit;
proc risk;
environment open = RDExamp.optimex;
/* Set analysis options. */
setoptions optsummary;
/* Create an optimization analysis. */
optimization Stock_Optimization
simulation = Stock_Sim
horizon = (1)
objective = return
subjectto = (es = (&ESPct))
bounds = RDExamp.stockbound;
/* Create the analysis project Stock_Opt_Proj. */
project Stock_Opt_Proj
data = (Mkt_Data)
portfolio = Stock_File
analysis = (Stock_Optimization)
numeraire = USD
rundate = "30May14"d
crossclass = cc1
out = Optimal_Stock_Results;
/* Run the analysis project. */
runproject Stock_Opt_Proj
options = (outall);
environment save;
run;
libname stockres clear;
