/*  EfFrontier.sas finds and fits an efficient frontier 
	for the portfolio.   */

	   proc risk;
			environment open = RDExamp.optimex;

	/* Set analysis options. */
      setoptions optsummary;

	/* Create an optimization analysis. */
	      optimization Eff_Frontier
	      simulation = Stock_Sim
	         horizon = (1)
		      objective = return
		      subjectto = (es = (0.023 to 0.038 by 0.001))
	         bounds = RDExamp.stockbound
	         lincon = RDExamp.stocklin;

	/* Create the analysis project Stock_Opt. */
	      project Stock2_Proj
	         data = (Mkt_Data)
	         portfolio = Stock_File
	         analysis = (Eff_Frontier)
	         numeraire = USD
	         rundate = "30May14"d
	         crossclass = cc1
         out = EF_Results;

	/* Run the analysis project. */
      runproject Stock2_Proj 
	         options = (outall);

      environment save;

   run;

/* Create library to Efficient Frontier results. */
	%macro createlib;
	   %let inpath=%sysfunc(pathname(RDExamp,L));
	   %if %index(&inpath,\) %then %let sep=\; %else %let sep=/;
	   libname effres "&loc.&sep.optimex&sep.ef_results";
	   %mend;
	%createlib;

/* Create a quadratic data set from the risk/return profile  */
	/* of the efficient frontier.                                */
	   data risk_return;
	      set effres.optsum
	      (keep = OptObjective OptConstraint);
			  OO2 = OptObjective**2;
	   ;

/* Output the parameter estimates from PROC REG. */
	   ods output ParameterEstimates = RDExamp.estimates
	      (drop= Model DF Dependent StdErr tValue Probt);

	/* OLS regression of the efficient frontier. */
	   proc reg data = risk_return;
	      model OptConstraint = OO2 OptObjective;
	   quit;

	   libname effres clear;
