/* RiskSetupA.sas creates the risk environment. */
proc risk;
/* Create a new environment. */
   environment new = RDExamp.optimex;
/* Create instrument variables. */
   declare instvars = (
           Company char 15 class label = "Issuing company");
/* Create risk factor variables. 
   Use the form 
           P_<ticker> num var
                      label "<company> share price"
                      refmap = (compref = "<company>")
		   */
   declare riskfactors = (
           P_XBBA num var
                  label = "Telco share price"
                  refmap = (compref = "Telco"),
           P_XBBB num var
                  label = "Bank share price"
                  refmap = (compref = "Bank"),
           P_XBBC num var
                  label = "Tech share price"
                  refmap = (compref = "Tech"),
           P_XBBD num var
                  label = "Utility share price"
                  refmap = (compref = "Utility"),
           P_XBBE num var
                  label = "Oil share price"
                  refmap = (compref = "Oil"),
           P_XBBF num var
                  label = "Auto share price"
                  refmap = (compref = "Auto"),
           P_XBBG num var
                  label = "Software share price"
                  refmap = (compref = "Software"),
           P_XBBH num var
                  label = "Energy share price"
                  refmap = (compref = "Energy"),
           P_XBBI num var
                  label = "Retail share price"
                  refmap = (compref = "Retail"),
           P_XBBJ num var
                  label = "Food share price"
                  refmap = (compref = "Food"));
/* Create a reference variable. */
   declare reference = (compref num var
                        label = "Company" );
/* Create a cross-classification. */
   crossclass cc1 (Company);
   environment save;
run;
/* Create a pricing method program. */
proc compile outlib = RDexamp.optimex
   environment = RDexamp.optimex
   package = Stock_Price;
/* Pricing function for stocks. */
   function stock_price(price)
   kind = pricing
   label = "Simple stock pricing function";
   return(price);
endsub;
/* Create the stock pricing method. */
method Stock_Price desc = "Simple stock pricing method"
   kind = Price;
   _value_ = compref.company;
endmethod;
run;
/* The COVAR macro is used to create a covariance matrix, which */
/* is needed for the covariance simulation. */
%covar("&loc", OptDat, "&loc", Cov_Data, Cov_Mat, RDExamp.optimex ,1,,,,);
/* Create the stock instrument and register the instrument data. */
proc risk;
   environment open = RDExamp.optimex;
/* Create a stock instrument. */
   instrument Stock
   label = "Stock"
   variables = (Holding, Company)
   methods = (price Stock_Price);
/* Register the instrument data. */
   instdata Stock_Data
   file = RDExamp.Inst_Data
   format = simple
   variables = (InstType InstID Holding Company);
/* Create a portfolio list for stocks. */
   sources Stock_List Stock_Data ;
/* Create a portfolio file for stocks. */
   read sources = Stock_List out = Stock_File;
/* Register the market data. */
   marketdata Mkt_Data
      file = RDExamp.Mkt_Data
      type = current;
/* Register the covariance matrix. */
   marketdata Cov_Mat
      file = RDExamp.Cov_Data
      type = covariance
      interval = weekday;
   environment save;
run;
/* Create the weight bounds. */
data RDExamp.stockbound;
input Company $ InstID $ lb ub;
datalines;
Telco XBBA . 1.0
Bank XBBB . 1.0
Tech XBBC . 1.0
Utility XBBD . 1.0
Oil XBBE . 1.0
Auto XBBF . 1.0
Software XBBG . 1.0
Energy XBBH . 1.0
Retail XBBI . 1.0
Food XBBJ . 1.0
;
