%macro CreateInstSet(inDir, inMktPrc, inWgt, inInstSet, outSet, value=1000000);
/* Begin PROC SQL. */
proc sql noprint;
/* Create a temporary output table for the portfolio file. */
create table temp_out
( 
InstType Char(8),
InstID Char(8),
P_ID Char(10),
Holding num,
Company Char(15)
);
/* Create a temporary table for rearranging MKT prices. */
create table temp_mktprc as
select *
from &inDir..&inMktPrc;
/* Create the MKT price table. */
create table new_mktprc
( P_ID Char(10),
Price num
);
/* Drop the date field from the temp MKT price table. */
alter table temp_mktprc
drop Date;
/* Populate the temporary out table with the values from the holding */
/* field to the portfolio value times the security weight. */
insert into temp_out (InstType, InstID,
P_ID, Holding,
Company)
select a.InstType, a.InstID,
a.Mkt_P,(b.wgt*&value),
a.Company
from &inDir..&inInstSet as a,
&inDir..&inWgt as b
where a.company = b.company;
/* Count the number of securities in the output table. */
/* Store the value in a SAS macro table. */
select count(P_ID)
into :n_mkt
from temp_out;
/* Read the values of P_ID into a series of macro variables. */
select P_ID
into :ID1 - :ID%left(&n_mkt)
from temp_out;
/* Loop over the # of IDs. */
%do i=1 %to &n_mkt;
/* Create a pointer to the current P_ID. */
%let tmpa = &&ID&i;
/* Select MKT price for the current P_ID. */
/* Store in a macro. */
select &tmpa
into :prc
from temp_mktprc;
/* Insert current P_ID and price into new MKT price table. */
insert into new_mktprc
values( "&tmpa", &prc );
%end ;
/* Update the temporary out table dividing holding by MKT price. */
update temp_out as a
set Holding = Holding / (
select Price
from new_mktprc as b
where a.P_ID = b.P_ID);
/* Round the holding value. */
update temp_out
set Holding = round(Holding);
/* End PROC SQL. */
quit;
/* Use a DATA step to update the output data set. */
data &inDir..&outSet;
set temp_out;
drop P_ID;
;
%mend CreateInstSet;
